@@ -1,5 +1,5 @@
 package Astro::FITS::CFITSIO;
-$VERSION = '1.00';
+$VERSION = '1.15_01';
 
 use strict;
 use Carp;
@@ -18,27 +18,48 @@ my @__names_no_short = qw(
                           fits_set_noise_bits
                           fits_get_tile_dim
                           fits_set_tile_dim
+                          fits_translate_keyword
+                          fits_translate_keywords
+                          fits_copy_cell2image
+                          fits_copy_image2cell
 		         );
 
 # perl -nle "next unless /^\s*#define\s+fits_/; (undef,\$l,\$s) = split ' '; print \"\$s => '\$l',\"" /usr/local/cfitsio/longnam.h
 
 my %__names = (
 	       ffiurl => 'fits_parse_input_url',
+	       ffifile => 'fits_parse_input_filename',
 	       ffrtnm => 'fits_parse_rootname',
+	       ffrwrg => 'fits_parse_range',
+	       ffrwrgll => 'fits_parse_rangell',
 	       ffourl => 'fits_parse_output_url',
 	       ffexts => 'fits_parse_extspec',
 	       ffextn => 'fits_parse_extnum',
 	       ffbins => 'fits_parse_binspec',
 	       ffbinr => 'fits_parse_binrange',
+	       ffdopn => 'fits_open_data',
+	       fftopn => 'fits_open_table',
+	       ffeopn => 'fits_open_extlist',
+	       ffiopn => 'fits_open_image',
 	       ffomem => 'fits_open_memfile',
 	       ffopen => 'fits_open_file',
+	       ffdkopn => 'fits_open_diskfile',
 	       ffreopen => 'fits_reopen_file',
 	       ffinit => 'fits_create_file',
+	       ffdkinit => 'fits_create_diskfile',
 	       ffimem => 'fits_create_memfile',
 	       fftplt => 'fits_create_template',
 	       ffflus => 'fits_flush_file',
+	       ffflsh => 'fits_flush_buffer',
+	       ffihtps => 'fits_init_https',
+	       ffchtps => 'fits_cleanup_https',
+	       ffvhtps => 'fits_verbose_https',
+	       ffshdwn => 'fits_show_download_progress',
+	       ffgtmo => 'fits_get_timeout',
+	       ffstmo => 'fits_set_timeout',
 	       ffclos => 'fits_close_file',
 	       ffdelt => 'fits_delete_file',
+	       ffexist => 'fits_file_exists',
 	       ffflnm => 'fits_file_name',
 	       ffflmd => 'fits_file_mode',
 	       ffurlt => 'fits_url_type',
@@ -49,12 +70,16 @@ my %__names = (
 	       ffgmsg => 'fits_read_errmsg',
 	       ffcmsg => 'fits_clear_errmsg',
 	       ffrprt => 'fits_report_error',
+	       ffpmrk => 'fits_write_errmark',
+	       ffcmrk => 'fits_clear_errmark',
+	       ffcmsg => 'fits_clear_errmsg',
 	       ffcmps => 'fits_compare_str',
 	       fftkey => 'fits_test_keyword',
 	       fftrec => 'fits_test_record',
 	       ffnchk => 'fits_null_check',
 	       ffkeyn => 'fits_make_keyn',
 	       ffnkey => 'fits_make_nkey',
+	       ffmkky => 'fits_make_key',
 	       ffgkcl => 'fits_get_keyclass',
 	       ffdtyp => 'fits_get_keytype',
 	       ffpsvc => 'fits_parse_value',
@@ -62,6 +87,7 @@ my %__names = (
 	       ffgthd => 'fits_parse_template',
 	       ffasfm => 'fits_ascii_tform',
 	       ffbnfm => 'fits_binary_tform',
+	       ffbnfmll => 'fits_binary_tformll',
 	       ffgabc => 'fits_get_tbcol',
 	       ffgrsz => 'fits_get_rowsize',
 	       ffgcdw => 'fits_get_col_display_width',
@@ -93,18 +119,23 @@ my %__names = (
 	       ffpkym => 'fits_write_key_dblcmp',
 	       ffpkyt => 'fits_write_key_triple',
 	       ffptdm => 'fits_write_tdim',
+	       ffptdmll => 'fits_write_tdimll',
 	       ffpkns => 'fits_write_keys_str',
 	       ffpknl => 'fits_write_keys_log',
 	       ffpknj => 'fits_write_keys_lng',
+	       ffpknjj => 'fits_write_keys_lnglng',
 	       ffpknf => 'fits_write_keys_fixflt',
 	       ffpkne => 'fits_write_keys_flt',
 	       ffpkng => 'fits_write_keys_fixdbl',
 	       ffpknd => 'fits_write_keys_dbl',
 	       ffcpky => 'fits_copy_key',
 	       ffphps => 'fits_write_imghdr',
+	       ffphpsll => 'fits_write_imghdrll',
 	       ffphpr => 'fits_write_grphdr',
+	       ffphprll => 'fits_write_grphdrll',
 	       ffphtb => 'fits_write_atblhdr',
 	       ffphbn => 'fits_write_btblhdr',
+	       ffphext => 'fits_write_exthdr',
 	       ffpktp => 'fits_write_key_template',
 	       ffghsp => 'fits_get_hdrspace',
 	       ffghps => 'fits_get_hdrpos',
@@ -115,6 +146,10 @@ my %__names = (
 	       ffgcrd => 'fits_read_card',
 	       ffgunt => 'fits_read_key_unit',
 	       ffgkyn => 'fits_read_keyn',
+	       ffgstr => 'fits_read_str',
+	       ffgksl => 'fits_read_key_strlen',
+	       ffgsky => 'fits_read_string_key',
+	       ffdstr => 'fits_delete_str',
 	       ffgky => 'fits_read_key',
 	       ffgkey => 'fits_read_keyword',
 	       ffgkys => 'fits_read_key_str',
@@ -126,16 +161,25 @@ my %__names = (
 	       ffgkym => 'fits_read_key_dblcmp',
 	       ffgkyt => 'fits_read_key_triple',
 	       ffgkls => 'fits_read_key_longstr',
+	       fffree => 'fits_free_memory',
+	       ffhdr2str => 'fits_hdr2str',
+	       ffcnvthdr2str => 'fits_convert_hdr2str',
 	       ffgtdm => 'fits_read_tdim',
+	       ffgtdmll => 'fits_read_tdimll',
 	       ffdtdm => 'fits_decode_tdim',
+	       ffdtdmll => 'fits_decode_tdimll',
 	       ffgkns => 'fits_read_keys_str',
 	       ffgknl => 'fits_read_keys_log',
 	       ffgknj => 'fits_read_keys_lng',
+	       ffgknjj => 'fits_read_keys_lnglng',
 	       ffgkne => 'fits_read_keys_flt',
 	       ffgknd => 'fits_read_keys_dbl',
 	       ffghpr => 'fits_read_imghdr',
+	       ffghprll => 'fits_read_imghdrll',
 	       ffghtb => 'fits_read_atblhdr',
+	       ffghtbll => 'fits_read_atblhdrll',
 	       ffghbn => 'fits_read_btblhdr',
+	       ffghbnll => 'fits_read_btblhdrll',
 	       ffh2st => 'fits_header2str',
 	       ffucrd => 'fits_update_card',
 	       ffuky => 'fits_update_key',
@@ -169,6 +213,7 @@ my %__names = (
 	       ffmkyc => 'fits_modify_key_cmp',
 	       ffmkfm => 'fits_modify_key_fixdblcmp',
 	       ffmkym => 'fits_modify_key_dblcmp',
+	       ffikey => 'fits_insert_card',
 	       ffirec => 'fits_insert_record',
 	       ffikyu => 'fits_insert_key_null',
 	       ffikys => 'fits_insert_key_str',
@@ -188,26 +233,37 @@ my %__names = (
 	       ffghdn => 'fits_get_hdu_num',
 	       ffghdt => 'fits_get_hdu_type',
 	       ffghad => 'fits_get_hduaddr',
+	       ffghadll => 'fits_get_hduaddrll',
 	       ffghof => 'fits_get_hduoff',
 	       ffgipr => 'fits_get_img_param',
+	       ffgiprll => 'fits_get_img_paramll',
 	       ffgidt => 'fits_get_img_type',
+	       ffinttyp => 'fits_get_inttype',
+	       ffgiet => 'fits_get_img_equivtype',
 	       ffgidm => 'fits_get_img_dim',
 	       ffgisz => 'fits_get_img_size',
+	       ffgiszll => 'fits_get_img_sizell',
 	       ffmahd => 'fits_movabs_hdu',
 	       ffmrhd => 'fits_movrel_hdu',
 	       ffmnhd => 'fits_movnam_hdu',
 	       ffthdu => 'fits_get_num_hdus',
 	       ffcrim => 'fits_create_img',
+	       ffcrimll => 'fits_create_imgll',
 	       ffcrtb => 'fits_create_tbl',
+	       ffcpht => 'fits_copy_hdutab',
 	       ffcrhd => 'fits_create_hdu',
 	       ffiimg => 'fits_insert_img',
+	       ffiimgll => 'fits_insert_imgll',
 	       ffitab => 'fits_insert_atbl',
 	       ffibin => 'fits_insert_btbl',
 	       ffrsim => 'fits_resize_img',
+	       ffrsimll => 'fits_resize_imgll',
 	       ffdhdu => 'fits_delete_hdu',
+	       ffcpfl => 'fits_copy_file',
 	       ffcopy => 'fits_copy_hdu',
 	       ffcphd => 'fits_copy_header',
 	       ffcpdt => 'fits_copy_data',
+	       ffwrhdu => 'fits_write_hdu',
 	       ffrdef => 'fits_set_hdustruc',
 	       ffhdef => 'fits_set_hdrsize',
 	       ffpthp => 'fits_write_theap',
@@ -225,90 +281,112 @@ my %__names = (
 	       ffgcno => 'fits_get_colnum',
 	       ffgcnn => 'fits_get_colname',
 	       ffgtcl => 'fits_get_coltype',
+	       ffgtclll => 'fits_get_coltypell',
+	       ffeqty => 'fits_get_eqcoltype',
+	       ffeqtyll => 'fits_get_eqcoltypell',
 	       ffgnrw => 'fits_get_num_rows',
+	       ffgnrwll => 'fits_get_num_rowsll',
 	       ffgncl => 'fits_get_num_cols',
 	       ffgacl => 'fits_get_acolparms',
 	       ffgbcl => 'fits_get_bcolparms',
+	       ffgbclll => 'fits_get_bcolparmsll',
 	       ffiter => 'fits_iterate_data',
 	       ffggpb => 'fits_read_grppar_byt',
+	       ffggpb => 'fits_read_grppar_sbyt',
 	       ffggpui => 'fits_read_grppar_usht',
 	       ffggpuj => 'fits_read_grppar_ulng',
 	       ffggpi => 'fits_read_grppar_sht',
 	       ffggpj => 'fits_read_grppar_lng',
+	       ffggpjj => 'fits_read_grppar_lnglng',
 	       ffggpk => 'fits_read_grppar_int',
 	       ffggpuk => 'fits_read_grppar_uint',
 	       ffggpe => 'fits_read_grppar_flt',
 	       ffggpd => 'fits_read_grppar_dbl',
 	       ffgpxv => 'fits_read_pix',
+	       ffgpxvll => 'fits_read_pixll',
 	       ffgpxf => 'fits_read_pixnull',
+	       ffgpxfll => 'fits_read_pixnullll',
 	       ffgpv => 'fits_read_img',
 	       ffgpf => 'fits_read_imgnull',
 	       ffgpvb => 'fits_read_img_byt',
+	       ffgpvsb => 'fits_read_img_sbyt',
 	       ffgpvui => 'fits_read_img_usht',
 	       ffgpvuj => 'fits_read_img_ulng',
 	       ffgpvi => 'fits_read_img_sht',
 	       ffgpvj => 'fits_read_img_lng',
+	       ffgpvjj => 'fits_read_img_lnglng',
 	       ffgpvuk => 'fits_read_img_uint',
 	       ffgpvk => 'fits_read_img_int',
 	       ffgpve => 'fits_read_img_flt',
 	       ffgpvd => 'fits_read_img_dbl',
 	       ffgpfb => 'fits_read_imgnull_byt',
+	       ffgpfsb => 'fits_read_imgnull_sbyt',
 	       ffgpfui => 'fits_read_imgnull_usht',
 	       ffgpfuj => 'fits_read_imgnull_ulng',
 	       ffgpfi => 'fits_read_imgnull_sht',
 	       ffgpfj => 'fits_read_imgnull_lng',
+	       ffgpfjj => 'fits_read_imgnull_lnglng',
 	       ffgpfuk => 'fits_read_imgnull_uint',
 	       ffgpfk => 'fits_read_imgnull_int',
 	       ffgpfe => 'fits_read_imgnull_flt',
 	       ffgpfd => 'fits_read_imgnull_dbl',
 	       ffg2db => 'fits_read_2d_byt',
+	       ffg2dsb => 'fits_read_2d_sbyt',
 	       ffg2dui => 'fits_read_2d_usht',
 	       ffg2duj => 'fits_read_2d_ulng',
 	       ffg2di => 'fits_read_2d_sht',
 	       ffg2dj => 'fits_read_2d_lng',
+	       ffg2djj => 'fits_read_2d_lnglng',
 	       ffg2duk => 'fits_read_2d_uint',
 	       ffg2dk => 'fits_read_2d_int',
 	       ffg2de => 'fits_read_2d_flt',
 	       ffg2dd => 'fits_read_2d_dbl',
 	       ffg3db => 'fits_read_3d_byt',
+	       ffg3dsb => 'fits_read_3d_sbyt',
 	       ffg3dui => 'fits_read_3d_usht',
 	       ffg3duj => 'fits_read_3d_ulng',
 	       ffg3di => 'fits_read_3d_sht',
 	       ffg3dj => 'fits_read_3d_lng',
+	       ffg3dj => 'fits_read_3d_lnglng',
 	       ffg3duk => 'fits_read_3d_uint',
 	       ffg3dk => 'fits_read_3d_int',
 	       ffg3de => 'fits_read_3d_flt',
 	       ffg3dd => 'fits_read_3d_dbl',
 	       ffgsv => 'fits_read_subset',
 	       ffgsvb => 'fits_read_subset_byt',
+	       ffgsvsb => 'fits_read_subset_sbyt',
 	       ffgsvui => 'fits_read_subset_usht',
 	       ffgsvuj => 'fits_read_subset_ulng',
 	       ffgsvi => 'fits_read_subset_sht',
 	       ffgsvj => 'fits_read_subset_lng',
+	       ffgsvjj => 'fits_read_subset_lnglng',
 	       ffgsvuk => 'fits_read_subset_uint',
 	       ffgsvk => 'fits_read_subset_int',
 	       ffgsve => 'fits_read_subset_flt',
 	       ffgsvd => 'fits_read_subset_dbl',
 	       ffgsfb => 'fits_read_subsetnull_byt',
+	       ffgsfsb => 'fits_read_subsetnull_sbyt',
 	       ffgsfui => 'fits_read_subsetnull_usht',
 	       ffgsfuj => 'fits_read_subsetnull_ulng',
 	       ffgsfi => 'fits_read_subsetnull_sht',
 	       ffgsfj => 'fits_read_subsetnull_lng',
+	       ffgsfjj => 'fits_read_subsetnull_lnglng',
 	       ffgsfuk => 'fits_read_subsetnull_uint',
 	       ffgsfk => 'fits_read_subsetnull_int',
 	       ffgsfe => 'fits_read_subsetnull_flt',
 	       ffgsfd => 'fits_read_subsetnull_dbl',
-	       fits_comp_img => 'fits_compress_img',
 	       fits_decomp_img => 'fits_decompress_img',
 	       ffgcv => 'fits_read_col',
 	       ffgcf => 'fits_read_colnull',
 	       ffgcvs => 'fits_read_col_str',
 	       ffgcvl => 'fits_read_col_log',
 	       ffgcvb => 'fits_read_col_byt',
+	       ffgcvsb => 'fits_read_col_sbyt',
 	       ffgcvui => 'fits_read_col_usht',
 	       ffgcvuj => 'fits_read_col_ulng',
 	       ffgcvi => 'fits_read_col_sht',
 	       ffgcvj => 'fits_read_col_lng',
+	       ffgcvjj => 'fits_read_col_lnglng',
 	       ffgcvuk => 'fits_read_col_uint',
 	       ffgcvk => 'fits_read_col_int',
 	       ffgcve => 'fits_read_col_flt',
@@ -321,10 +399,12 @@ my %__names = (
 	       ffgcfs => 'fits_read_colnull_str',
 	       ffgcfl => 'fits_read_colnull_log',
 	       ffgcfb => 'fits_read_colnull_byt',
+	       ffgcfsb => 'fits_read_colnull_sbyt',
 	       ffgcfui => 'fits_read_colnull_usht',
 	       ffgcfuj => 'fits_read_colnull_ulng',
 	       ffgcfi => 'fits_read_colnull_sht',
 	       ffgcfj => 'fits_read_colnull_lng',
+	       ffgcfjj => 'fits_read_colnull_lnglng',
 	       ffgcfuk => 'fits_read_colnull_uint',
 	       ffgcfk => 'fits_read_colnull_int',
 	       ffgcfe => 'fits_read_colnull_flt',
@@ -332,35 +412,45 @@ my %__names = (
 	       ffgcfc => 'fits_read_colnull_cmp',
 	       ffgcfm => 'fits_read_colnull_dblcmp',
 	       ffgdes => 'fits_read_descript',
+	       ffgdesll => 'fits_read_descriptll',
 	       ffgdess => 'fits_read_descripts',
+	       ffgdessll => 'fits_read_descriptsll',
 	       ffgtbb => 'fits_read_tblbytes',
 	       ffpgpb => 'fits_write_grppar_byt',
+	       ffpgpsb => 'fits_write_grppar_sbyt',
 	       ffpgpui => 'fits_write_grppar_usht',
 	       ffpgpuj => 'fits_write_grppar_ulng',
 	       ffpgpi => 'fits_write_grppar_sht',
 	       ffpgpj => 'fits_write_grppar_lng',
+	       ffpgpjj => 'fits_write_grppar_lngj',
 	       ffpgpuk => 'fits_write_grppar_uint',
 	       ffpgpk => 'fits_write_grppar_int',
 	       ffpgpe => 'fits_write_grppar_flt',
 	       ffpgpd => 'fits_write_grppar_dbl',
 	       ffppx => 'fits_write_pix',
+	       ffppxll => 'fits_write_pixll',
 	       ffppxn => 'fits_write_pixnull',
+	       ffppxnll => 'fits_write_pixnullll',
 	       ffppr => 'fits_write_img',
 	       ffpprb => 'fits_write_img_byt',
+	       ffpprsb => 'fits_write_img_sbyt',
 	       ffpprui => 'fits_write_img_usht',
 	       ffppruj => 'fits_write_img_ulng',
 	       ffppri => 'fits_write_img_sht',
 	       ffpprj => 'fits_write_img_lng',
+	       ffpprjj => 'fits_write_img_lnglng',
 	       ffppruk => 'fits_write_img_uint',
 	       ffpprk => 'fits_write_img_int',
 	       ffppre => 'fits_write_img_flt',
 	       ffpprd => 'fits_write_img_dbl',
 	       ffppn => 'fits_write_imgnull',
 	       ffppnb => 'fits_write_imgnull_byt',
+	       ffppnsb => 'fits_write_imgnull_sbyt',
 	       ffppnui => 'fits_write_imgnull_usht',
 	       ffppnuj => 'fits_write_imgnull_ulng',
 	       ffppni => 'fits_write_imgnull_sht',
 	       ffppnj => 'fits_write_imgnull_lng',
+	       ffppnjj => 'fits_write_imgnull_lnglng',
 	       ffppnuk => 'fits_write_imgnull_uint',
 	       ffppnk => 'fits_write_imgnull_int',
 	       ffppne => 'fits_write_imgnull_flt',
@@ -368,41 +458,50 @@ my %__names = (
 	       ffppru => 'fits_write_img_null',
 	       ffpprn => 'fits_write_null_img',
 	       ffp2db => 'fits_write_2d_byt',
+	       ffp2dsb => 'fits_write_2d_sbyt',
 	       ffp2dui => 'fits_write_2d_usht',
 	       ffp2duj => 'fits_write_2d_ulng',
 	       ffp2di => 'fits_write_2d_sht',
 	       ffp2dj => 'fits_write_2d_lng',
+	       ffp2djj => 'fits_write_2d_lnglng',
 	       ffp2duk => 'fits_write_2d_uint',
 	       ffp2dk => 'fits_write_2d_int',
 	       ffp2de => 'fits_write_2d_flt',
 	       ffp2dd => 'fits_write_2d_dbl',
 	       ffp3db => 'fits_write_3d_byt',
+	       ffp3dsb => 'fits_write_3d_sbyt',
 	       ffp3dui => 'fits_write_3d_usht',
 	       ffp3duj => 'fits_write_3d_ulng',
 	       ffp3di => 'fits_write_3d_sht',
 	       ffp3dj => 'fits_write_3d_lng',
+	       ffp3djj => 'fits_write_3d_lnglng',
 	       ffp3duk => 'fits_write_3d_uint',
 	       ffp3dk => 'fits_write_3d_int',
 	       ffp3de => 'fits_write_3d_flt',
 	       ffp3dd => 'fits_write_3d_dbl',
 	       ffpss => 'fits_write_subset',
 	       ffpssb => 'fits_write_subset_byt',
+	       ffpsssb => 'fits_write_subset_sbyt',
 	       ffpssui => 'fits_write_subset_usht',
 	       ffpssuj => 'fits_write_subset_ulng',
 	       ffpssi => 'fits_write_subset_sht',
 	       ffpssj => 'fits_write_subset_lng',
+	       ffpssjj => 'fits_write_subset_lnglng',
 	       ffpssuk => 'fits_write_subset_uint',
 	       ffpssk => 'fits_write_subset_int',
 	       ffpsse => 'fits_write_subset_flt',
 	       ffpssd => 'fits_write_subset_dbl',
+	       ffprwu => 'fits_write_nullrows',
 	       ffpcl => 'fits_write_col',
 	       ffpcls => 'fits_write_col_str',
 	       ffpcll => 'fits_write_col_log',
 	       ffpclb => 'fits_write_col_byt',
+	       ffpclsb => 'fits_write_col_sbyt',
 	       ffpclui => 'fits_write_col_usht',
 	       ffpcluj => 'fits_write_col_ulng',
 	       ffpcli => 'fits_write_col_sht',
 	       ffpclj => 'fits_write_col_lng',
+	       ffpcljj => 'fits_write_col_lnglng',
 	       ffpcluk => 'fits_write_col_uint',
 	       ffpclk => 'fits_write_col_int',
 	       ffpcle => 'fits_write_col_flt',
@@ -415,10 +514,12 @@ my %__names = (
 	       ffpcns => 'fits_write_colnull_str',
 	       ffpcnl => 'fits_write_colnull_log',
 	       ffpcnb => 'fits_write_colnull_byt',
+	       ffpcnsb => 'fits_write_colnull_sbyt',
 	       ffpcnui => 'fits_write_colnull_usht',
 	       ffpcnuj => 'fits_write_colnull_ulng',
 	       ffpcni => 'fits_write_colnull_sht',
 	       ffpcnj => 'fits_write_colnull_lng',
+	       ffpcnjj => 'fits_write_colnull_lnglng',
 	       ffpcnuk => 'fits_write_colnull_uint',
 	       ffpcnk => 'fits_write_colnull_int',
 	       ffpcne => 'fits_write_colnull_flt',
@@ -428,15 +529,20 @@ my %__names = (
 	       fftheap => 'fits_test_heap',
 	       ffptbb => 'fits_write_tblbytes',
 	       ffirow => 'fits_insert_rows',
+	       ffdrrg => 'fits_delete_rowrange',
 	       ffdrow => 'fits_delete_rows',
 	       ffdrws => 'fits_delete_rowlist',
+	       ffdrwsll => 'fits_delete_rowlistll',
 	       fficol => 'fits_insert_col',
 	       fficls => 'fits_insert_cols',
 	       ffdcol => 'fits_delete_col',
 	       ffcpcl => 'fits_copy_col',
+	       ffccls => 'fits_copy_cols',
+	       ffcprw => 'fits_copy_rows',
 	       ffmvec => 'fits_modify_vector_len',
 	       ffgics => 'fits_read_img_coord',
 	       ffgtcs => 'fits_read_tbl_coord',
+	       ffgicsa => 'fits_read_img_coord_version',
 	       ffwldp => 'fits_pix_to_world',
 	       ffxypx => 'fits_world_to_pix',
 	       ffgiwcs => 'fits_get_image_wcs_keys',
@@ -455,6 +561,7 @@ my %__names = (
 	       ffgtrm => 'fits_remove_group',
 	       ffgtcp => 'fits_copy_group',
 	       ffgtmg => 'fits_merge_groups',
+	       ffmbyt => 'fits_seek',
 	       ffgtcm => 'fits_compact_group',
 	       ffgtvf => 'fits_verify_group',
 	       ffgtop => 'fits_open_group',
@@ -520,6 +627,8 @@ my @__constants = qw(
 		     BYTE_IMG
 		     CASEINSEN
 		     CASESEN
+		     CFITSIO_MAJOR
+		     CFITSIO_MINOR
 		     COL_NOT_FOUND
 		     COL_NOT_UNIQUE
 		     COL_TOO_WIDE
@@ -559,6 +668,7 @@ my @__constants = qw(
 		     KEY_NO_EXIST
 		     KEY_OUT_BOUNDS
 		     LONG_IMG
+		     LONGLONG_IMG
 		     MAXHDU
 		     MEMBER_NOT_FOUND
 		     MEMORY_ALLOCATION
@@ -627,6 +737,7 @@ my @__constants = qw(
 		     SHORT_IMG
 		     TBIT
 		     TBYTE
+		     TSBYTE
 		     TCOMPLEX
 		     TDBLCOMPLEX
 		     TDOUBLE
@@ -634,6 +745,7 @@ my @__constants = qw(
 		     TINT
 		     TLOGICAL
 		     TLONG
+		     TLONGLONG
 		     TOO_MANY_DRIVERS
 		     TOO_MANY_FILES
 		     TOO_MANY_HDUS_TRACKED
@@ -852,7 +964,8 @@ a Astro::FITS::CFITSIO "object" one would call C<open_file()>, C<create_file()>
 C<create_template()>:
 
     my $status = 0;
-    my $fptr = Astro::FITS::CFITSIO::open_file($filename,Astro::FITS::CFITSIO::READONLY(),$status);
+    my $fptr = Astro::FITS::CFITSIO::open_file($filename,
+                        Astro::FITS::CFITSIO::READONLY(),$status);
 
     $fptr->read_key_str('NAXIS1',$naxis1,undef,$status);
 
@@ -860,6 +973,22 @@ Note that the object-oriented forms of function names are only available for
 those cfitsio routines which accept a C<fitsfile*> data-type as the first
 argument.
 
+As an added benefit, whenever a filehandle goes out of scope, B<ffclos()>
+is automatically closed:
+
+    {
+      my $fptr = Astro::FITS::CFITSIO::open_file($filename,
+                        Astro::FITS::CFITSIO::READWRITE(),$status);
+      [manipulate $fptr]
+
+      # neither of the following are needed
+      # ffclos($fptr,$status);
+      # $fptr->close_file($status);
+    }
+
+It there is an error, it will B<croak()>.
+
+
 =head1 NAME SPACE
 
 All cfitsio routines, with the exception of C<fits_iterate_data()> and
@@ -911,14 +1040,47 @@ comment would be roughly equivalent:
 
 =head2 Output Variables
 
-Calling cfitsio routines which read data from FITS files causes the output
-variable to be transformed into a Perl array of the appropriate dimensions.
-The exception to this is if one wants the output to be in the machine-native
-format (e.g., for use with PDL). In this case you can use the routine
-C<PerlyUnpacking(0)>.  Then all output variables will become scalars
-containing the appropriate data. The exception here is with routines which
-read arrays of strings (e.g., C<fits_read_col_str()>).
-In this case the output is again a Perl array reference.
+Calling cfitsio routines which read data from FITS files causes the
+output variable to be transformed into a Perl array of the appropriate
+dimensions.  The exception to this is if one wants the output to be in
+the machine-native format (e.g., for use with PDL).
+Then all output variables will become scalars containing the
+appropriate data. The exception here is with routines which read
+arrays of strings (e.g., C<fits_read_col_str()>).  In this case the
+output is again a Perl array reference.
+
+There are two ways to specify how data are retrieved.  The behavior
+can be specified either globally or on a per filehandle basis.  The
+global selection is done by calling the B<PerlyUnpacking> function.
+This sets the behavior for I<all> file handles which do not
+I<explicitly> choose not to follow it.
+
+  # turn ON unpacking into Perl arrays.  This is the default
+  PerlyUnpacking(1);
+
+  # turn OFF unpacking into Perl arrays, i.e. put in machine-native
+  # format
+  PerlyUnpacking(0);
+
+  # retrieve the current state:
+  $state = PerlyUnpacking();
+
+To change the behavior for a particular file handle, use the
+B<perlyunpacking> method.  The default behavior for a file handle
+is to track what is done with B<PerlyUnpacking()>
+
+  # track PerlyUnpacking().  This is the default
+  $fptr->perlyunpacking(-1);
+
+  # turn ON unpacking into Perl arrays
+  $fptr->perlyunpacking(1);
+
+  # turn OFF unpacking into Perl arrays
+  $fptr->perlyunpacking(0);
+
+  # retrieve the current state:
+  $state = $fptr->perlyunpacking;
+
 
 =head1 EXAMPLES
 
@@ -1039,21 +1201,33 @@ FIXME
 
 =head1 AUTHOR
 
-Pete Ratzlaff <pratzlaff@cfa.harvard.edu>, with a great deal of code taken
-from Karl Glazebrook's PGPLOT module.
+Pete Ratzlaff E<lt>pratzlaff@cfa.harvard.eduE<gt>, with a great deal
+of code taken from Karl Glazebrook's PGPLOT module.
 
 Contributors include:
 
 =over 4
 
-=item Tim Jenness <t.jenness@jach.hawaii.edu>
+=item Diab Jerius, E<lt>djerius@cpan.orgE<gt>
+
+general improvements
+
+=item Tim Jenness, E<lt>t.jenness@jach.hawaii.eduE<gt>
 
 convenience routines
 
-=item Tim Conrow <tim@ipac.caltech.edu>
+=item Tim Conrow, E<lt>tim@ipac.caltech.eduE<gt>
 
 function implementations, bug fixes
 
 =back
 
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2002,2004,2006,2011 by the Smithsonian Astrophysical
+Observatory.
+
+This software is released under the same terms as Perl. A copy of the
+Perl license may be obtained at http://dev.perl.org/licenses/
+
 =cut
